# coding: utf-8

"""
    应用存储  API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ZSGF.Client.models.j_object_api_result import JObjectApiResult

class TestJObjectApiResult(unittest.TestCase):
    """JObjectApiResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JObjectApiResult:
        """Test JObjectApiResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JObjectApiResult`
        """
        model = JObjectApiResult()
        if include_optional:
            return JObjectApiResult(
                code = 56,
                err = '',
                data = {
                    'key' : [
                        null
                        ]
                    }
            )
        else:
            return JObjectApiResult(
        )
        """

    def testJObjectApiResult(self):
        """Test JObjectApiResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    应用存储  API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.3"

# import apis into sdk package
from ZSGF.Client.api.file_api import FileApi

# import ApiClient
from ZSGF.Client.api_response import ApiResponse
from ZSGF.Client.api_client import ApiClient
from ZSGF.Client.configuration import Configuration
from ZSGF.Client.exceptions import OpenApiException
from ZSGF.Client.exceptions import ApiTypeError
from ZSGF.Client.exceptions import ApiValueError
from ZSGF.Client.exceptions import ApiKeyError
from ZSGF.Client.exceptions import ApiAttributeError
from ZSGF.Client.exceptions import ApiException

# import models into sdk package
from ZSGF.Client.models.j_object_api_result import JObjectApiResult



# coding: utf-8

"""
    应用存储  API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ZSGF.Client.api.file_api import FileApi


class TestFileApi(unittest.TestCase):
    """FileApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FileApi()

    def tearDown(self) -> None:
        pass

    def test_file_create_folder(self) -> None:
        """Test case for file_create_folder

        创建文件夹
        """
        pass

    def test_file_delete(self) -> None:
        """Test case for file_delete

        删除文件
        """
        pass

    def test_file_rename(self) -> None:
        """Test case for file_rename

        重命名文件
        """
        pass

    def test_file_upload(self) -> None:
        """Test case for file_upload

        上传文件
        """
        pass

    def test_files(self) -> None:
        """Test case for files

        文件列表
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    应用存储  API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ZSGF.Client.models.j_object_api_result import JObjectApiResult



# coding: utf-8

"""
    应用存储  API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "ZSGF.Client"
VERSION = "1.0.3"
PYTHON_REQUIRES = ">= 3.8"
REQUIRES = [
    "urllib3 >= 1.25.3, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="应用存储  API 文档",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="https://github.com/wz101010/zsgf-python",
    keywords=["OpenAPI", "OpenAPI-Generator", "应用存储  API 文档"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description="""\
    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
    """,  # noqa: E501
    package_data={"ZSGF.Client": ["py.typed"]},
)